#[repr(C)]
pub struct Mat44T {Show 16 fields
pub xx: f32,
pub xy: f32,
pub xz: f32,
pub xw: f32,
pub yx: f32,
pub yy: f32,
pub yz: f32,
pub yw: f32,
pub zx: f32,
pub zy: f32,
pub zz: f32,
pub zw: f32,
pub wx: f32,
pub wy: f32,
pub wz: f32,
pub ww: f32,
}
Performs copy-assignment from source. Read more
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.