#[repr(C)]
pub struct CreationGraphContextT {Show 17 fields
pub rb: *mut RendererBackendI,
pub device_affinity_mask: u32,
pub default_instance: bool,
pub _padding_258: [c_char; 3],
pub ta: *mut TempAllocatorI,
pub requested_tasks: *mut *mut CreationGraphTaskT,
pub res_buf: [*mut RendererResourceCommandBufferO; 2],
pub cmd_buf: *mut RendererCommandBufferO,
pub event_context: *mut c_void,
pub entity_id: u64,
pub entity_ctx: *mut EntityContextO,
pub force_build_node: TtIdT,
pub force_build_cache_tag: StrhashT,
pub shader_repository: *mut ShaderRepositoryO,
pub event_id: StrhashT,
pub tt: *mut TheTruthO,
pub shader_context: *mut ShaderSystemContextO,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.