#[repr(C)]
pub struct CreationGraphOutputNodeTypeT {
pub node_name_hash: StrhashT,
pub display_name: *const c_char,
pub asset_label: *const AssetLabelT,
pub size: u64,
pub write_wire: Option<unsafe extern "C" fn(ctx: *mut CreationGraphInterpreterContextT, wire: u32, data: *const c_void)>,
pub create_thumbnail: Option<unsafe extern "C" fn(data: *const c_void, thumbnail_desc: *const RendererImageDescT, rb: *mut RendererBackendI, res_buf: *mut RendererResourceCommandBufferO, cmd_buf: *mut RendererCommandBufferO, res: *mut RendererHandleT)>,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.