#[repr(C)]
pub struct CreationGraphPreviewI {
pub output_name: StrhashT,
pub create: Option<unsafe extern "C" fn(allocator: *mut AllocatorI, data: *const c_void) -> *mut CreationGraphPreviewO>,
pub destroy: Option<unsafe extern "C" fn(inst: *mut CreationGraphPreviewO, allocator: *mut AllocatorI)>,
pub render: Option<unsafe extern "C" fn(inst: *mut CreationGraphPreviewO, tt: *mut TheTruthO, asset: TtIdT, args: *const RenderArgsT)>,
pub ui: Option<unsafe extern "C" fn(inst: *mut CreationGraphPreviewO, args: *const AssetPreviewApiUiArgsT)>,
pub create_entity: Option<unsafe extern "C" fn(inst: *mut CreationGraphPreviewO, tt: *mut TheTruthO, asset: TtIdT, entity_ctx: *mut EntityContextO, result: *mut EntityT)>,
pub toolbars: Option<unsafe extern "C" fn(inst: *mut CreationGraphPreviewO, ta: *mut TempAllocatorI, args: *const AssetPreviewApiUiArgsT) -> *mut ToolbarI>,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.