#[repr(C)]
pub struct GpuSimulationChannelBufferDataT {
pub buffer: RendererHandleT,
pub buffer_resource_state: u16,
pub _padding_14: [c_char; 6],
pub buffer_header_size: u32,
pub buffer_header_count_offset: u32,
pub buffer_header_stride_offset: u32,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.