#[repr(C)]
pub struct AssetBrowserConfigT {
pub tt: *mut TheTruthO,
pub asset_browser: TtIdT,
pub undo_stack: *mut UndoStackI,
pub tab: *mut TabI,
pub open_ud: *mut c_void,
pub open: Option<unsafe extern "C" fn(open_ud: *mut c_void, ui: *mut UiO, tab: *mut TabI, asset: TtIdT)>,
pub disable_thumbnail_generation: bool,
pub _padding_281: [c_char; 3],
pub num_custom_menu_items: u32,
pub custom_menu_items: *const AssetBrowserCustomMenuItemI,
pub save_interface: *mut AssetSaveI,
pub ui_renderer: *mut UiRendererO,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.