#[repr(C)]
pub struct GraphDrawConnectorsArgsT {Show 17 fields
pub prop_args: *mut PropertiesUiArgsT,
pub graph_id: TtIdT,
pub connectors: *mut GraphNodeConnectorsT,
pub in_connected: u32,
pub out_connected: u32,
pub item_rect: RectT,
pub graph_scale: f32,
pub property_panel_mode: bool,
pub show_removed_inherited: bool,
pub _padding_439: [c_char; 2],
pub expanded: *mut SetT,
pub graph: *mut GraphO,
pub node_id: TtIdT,
pub node_prototype_relation: u32,
pub node_idx: u32,
pub draw_in_connector_label_and_property: Option<unsafe extern "C" fn(graph: *mut GraphO, node_idx: u32, connector: *mut GraphConnectorT, editable: bool, r: RectT, args: *mut PropertiesUiArgsT) -> RectT>,
pub draw_out_connector_label: Option<unsafe extern "C" fn(graph: *mut GraphO, connector: *mut GraphConnectorT, editable: bool, r: RectT, args: *mut PropertiesUiArgsT, alignment: u32) -> RectT>,
}
expanded: *mut SetTdraw_in_connector_label_and_property: Option<unsafe extern "C" fn(graph: *mut GraphO, node_idx: u32, connector: *mut GraphConnectorT, editable: bool, r: RectT, args: *mut PropertiesUiArgsT) -> RectT>
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.