#[repr(C)]
pub struct TreeViewSetupT {
pub allocator: *mut AllocatorI,
pub undo_stack: *mut UndoStackI,
pub tt: *mut TheTruthO,
pub keyboard_interaction: Option<unsafe extern "C" fn(state: *mut c_void, tree: *mut TreeViewO, ui: *mut UiO, is_first_responder: bool)>,
pub root: TtIdT,
pub cache_tree_heights: bool,
pub _padding_165: [c_char; 7],
pub state: *mut c_void,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.