#[repr(C)]
pub struct TreeViewUiResT {
pub focus_changed: bool,
pub _padding_176: [c_char; 7],
pub focus: TtIdT,
pub selection_changed: bool,
pub focus_on_tree_background: bool,
pub _padding_186: [c_char; 6],
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.