#[repr(C)]
pub struct ConstraintComponentT {Show 17 fields
pub type_: ConstraintType,
pub enabled: bool,
pub was_enabled: bool,
pub _padding_226: [c_char; 2],
pub blend_time: f32,
pub blend: f32,
pub constrained_entity: EntityT,
pub constrained_node_idx: u32,
pub _padding_239: [c_char; 4],
pub goal_entity: EntityT,
pub goal_node_idx: u32,
pub _padding_246: [c_char; 4],
pub goal_position: Vec3T,
pub match_rotation: bool,
pub _padding_254: [c_char; 3],
pub goal_rotation: Vec4T,
pub __bindgen_anon_1: ConstraintComponentTBindgenTy1,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.