#[repr(C)]
pub struct GraphInterpreterDebuggerBreakpointT {
pub breakpoint: TtIdT,
pub subgraph_node: TtIdT,
pub graph_id: TtIdT,
pub subgraph_id: TtIdT,
pub step_node_id: TtIdT,
pub breakpoint_unique_id: u64,
pub subgraph_node_unique_id: u64,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.