#[repr(C)]
pub struct RenderGraphLayerSortKeyT {
pub layer_name: StrhashT,
pub sort_key: u64,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.