#[repr(C)]
pub struct RendererTopLevelAccelerationStructureInstanceT {
pub transform: Mat44T,
pub shader_info_idx: u32,
pub _bitfield_align_1: [u32; 0],
pub _bitfield_1: __BindgenBitfieldUnit<[u8; 3]>,
pub __bindgen_padding_0: u8,
pub mask: u8,
pub _padding_333: [c_char; 3],
pub _bitfield_align_2: [u8; 0],
pub _bitfield_2: __BindgenBitfieldUnit<[u8; 1]>,
pub blas_handle: RendererHandleT,
}
blas_handle: RendererHandleT
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.