#[repr(C)]
pub struct CameraControllerComponentT {Show 13 fields
pub disable_input: bool,
pub _padding_24: [c_char; 3],
pub mode: camera_controller_mode,
pub translation_speed: f32,
pub rotation_speed: f32,
pub translation_damping: f32,
pub translation: Vec3T,
pub damped_translation: Vec3T,
pub rotation: Vec2T,
pub focus_point: Vec3T,
pub zoom: f32,
pub spin: Vec2T,
pub pan: Vec2T,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.