#[repr(C)]
pub struct Draw2dStyleT {
pub color: ColorSrgbT,
pub line_width: f32,
pub feather_width: f32,
pub feather: u32,
pub clip: u32,
pub _padding_174: [c_char; 4],
pub font: *const Draw2dFontT,
pub font_scale: f32,
pub include_alpha: bool,
pub _padding_184: [c_char; 3],
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.