#[repr(C)]
pub struct TabVt {Show 30 fields
pub name: *const c_char,
pub name_hash: StrhashT,
pub create_menu_name: Option<unsafe extern "C" fn() -> *const c_char>,
pub create_menu_category: Option<unsafe extern "C" fn() -> *const c_char>,
pub create: Option<unsafe extern "C" fn(context: *mut TabCreateContextT, ui: *mut UiO) -> *mut TabI>,
pub destroy: Option<unsafe extern "C" fn(inst: *mut TabO)>,
pub ui: Option<unsafe extern "C" fn(inst: *mut TabO, ui: *mut UiO, uistyle: *const UiStyleT, rect: RectT)>,
pub ui_serial: Option<unsafe extern "C" fn(inst: *mut TabO, ui: *mut UiO, uistyle: *const UiStyleT, rect: RectT)>,
pub hidden_update: Option<unsafe extern "C" fn(inst: *mut TabO)>,
pub title: Option<unsafe extern "C" fn(inst: *mut TabO, ui: *mut UiO) -> *const c_char>,
pub has_custom_tabbar_border_color: Option<unsafe extern "C" fn(inst: *mut TabO, color: *mut ColorSrgbT) -> bool>,
pub set_root: Option<unsafe extern "C" fn(inst: *mut TabO, tt: *mut TheTruthO, root: TtIdT)>,
pub root: Option<unsafe extern "C" fn(inst: *mut TabO) -> TabVtRootT>,
pub restore_settings: Option<unsafe extern "C" fn(inst: *mut TabO, tt: *mut TheTruthO, settings_id: TtIdT)>,
pub save_settings: Option<unsafe extern "C" fn(inst: *mut TabO, tt: *mut TheTruthO) -> TtIdT>,
pub can_close: Option<unsafe extern "C" fn(inst: *mut TabO) -> bool>,
pub focus_event: Option<unsafe extern "C" fn(inst: *mut TabO, from: *mut TabI, event: TabFocusEvent, tt: *mut TheTruthO, object: TtIdT, selection: *const TtIdT, selection_n: u32)>,
pub feed_events: Option<unsafe extern "C" fn(inst: *mut TabO, events: *const InputEventT, count: u32, args: *mut DockingFeedEventsArgsT)>,
pub process_dropped_os_files: Option<unsafe extern "C" fn(inst: *mut TabO, ui: *mut UiO, files: *mut *mut c_char, num_files: u32)>,
pub toolbars: Option<unsafe extern "C" fn(inst: *mut TabO, ta: *mut TempAllocatorI) -> *mut ToolbarI>,
pub custom_padding: Option<unsafe extern "C" fn(inst: *mut TabO, ui: *mut UiO, content_r: *mut RectT, safety_padding: f32)>,
pub need_update: Option<unsafe extern "C" fn(inst: *mut TabO) -> bool>,
pub hot_reload: Option<unsafe extern "C" fn(inst: *mut TabO)>,
pub entity_context: Option<unsafe extern "C" fn(inst: *mut TabO) -> *mut EntityContextO>,
pub viewer_render_args: Option<unsafe extern "C" fn(inst: *mut TabO, args: *mut ViewerRenderArgsT)>,
pub cant_be_pinned: bool,
pub run_as_job: bool,
pub dont_restore_at_startup: bool,
pub dont_restore_root_asset_at_startup: bool,
pub _padding_274: [c_char; 4],
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.