#[repr(C)]
pub struct UiButtonT {Show 13 fields
pub id: u64,
pub rect: RectT,
pub visible_rect: RectT,
pub icon: u32,
pub _padding_407: [c_char; 4],
pub text: *const c_char,
pub text_color: *const ColorSrgbT,
pub tooltip: *const c_char,
pub text_offset_y: f32,
pub is_disabled: bool,
pub hide_background: bool,
pub hide_margins: bool,
pub _padding_417: [c_char; 1],
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.