#[repr(C)]
pub struct UiInputStateT {Show 45 fields
pub time: f64,
pub scale: Vec2T,
pub offset: Vec2T,
pub mouse_pos: Vec2T,
pub mouse_move: Vec2T,
pub mouse_wheel: f32,
pub left_mouse_pressed: bool,
pub left_mouse_released: bool,
pub left_mouse_is_down: bool,
pub right_mouse_pressed: bool,
pub right_mouse_released: bool,
pub right_mouse_is_down: bool,
pub middle_mouse_pressed: bool,
pub middle_mouse_released: bool,
pub middle_mouse_is_down: bool,
pub back_mouse_pressed: bool,
pub back_mouse_released: bool,
pub back_mouse_is_down: bool,
pub forward_mouse_pressed: bool,
pub forward_mouse_released: bool,
pub forward_mouse_is_down: bool,
pub _padding_166: [c_char; 5],
pub left_mouse_pressed_at_time: f64,
pub mouse_move_at_time: f64,
pub double_click: bool,
pub triple_click: bool,
pub pen_pressed: bool,
pub pen_released: bool,
pub pen_is_down: bool,
pub touch_pressed: bool,
pub touch_released: bool,
pub touch_is_down: bool,
pub pressure: f32,
pub pen_erase: bool,
pub _padding_194: [c_char; 3],
pub key_is_down: *mut bool,
pub key_pressed: *mut bool,
pub key_released: *mut bool,
pub key_repeated: *mut bool,
pub modifiers: u32,
pub edit_key_pressed: [bool; 19],
pub _padding_210: [c_char; 1],
pub num_text_input: u32,
pub text_input: [u32; 256],
pub _padding_215: [c_char; 4],
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.