#[repr(C)]
pub struct UiTexteditT {
pub id: u64,
pub rect: RectT,
pub is_disabled: bool,
pub is_password: bool,
pub _padding_548: [c_char; 6],
pub default_text: *const c_char,
pub select_all_on_mouse_activate: bool,
pub scroll_to_end: bool,
pub select_all_on_startup: bool,
pub _padding_565: [c_char; 1],
pub select: UiTexteditTBindgenTy1,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.