#[repr(C)]
pub struct UiTitlebarT {
pub id: u64,
pub rect: RectT,
pub has_focus: bool,
pub is_maximized: bool,
pub _padding_840: [c_char; 6],
pub caption: *const c_char,
pub border_width: f32,
pub caption_height: f32,
pub caption_padding: f32,
pub _padding_848: [c_char; 4],
pub icon_texture: u32,
pub _padding_852: [c_char; 4],
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.