#[repr(C)]
pub struct UiTreeT {
pub ud: *mut c_void,
pub root: u64,
pub item_height: f32,
pub rect: RectT,
pub _padding_26: [c_char; 4],
pub node_ui: Option<unsafe extern "C" fn(ui: *mut UiO, uistyle: *const UiStyleT, item_id: u64, rect: RectT, ud: *mut c_void, node: u64, parent: u64, child_idx: u64)>,
pub node_children: Option<unsafe extern "C" fn(ud: *mut c_void, node: u64, children: *mut u64, n: u32) -> u32>,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.